local M = {}

local helper = require('scenario/scenariohelper')
local logTag = 'jamboree_race'

local finalWaypointName = 'scenario_finish1'
local playerInstance = 'scenario_player0'
local running = false
local playerWon = false
local aiWon = false

local function reset()
  running = false
  playerWon = false
  aiWon = false
end

local function fail(reason)
  scenario_scenarios.finish({failed = reason})
  reset()
end

local function success(reason)
  scenario_scenarios.finish({msg = reason})
  reset()
end

local racers = {"scenario_opponent1", "scenario_opponent3", "scenario_opponent4", "scenario_opponent5", "scenario_opponent2"}
local filenames = {"jam_opponent1-pickupbeast3", "jam_opponent3-roamerlandc", "jam_opponent4-vanace", "jam_opponent5-autobellodune", "jam_opponent2-hopperbeach"}

local function onRaceStart()
    local recordings = {}
    for i, v in ipairs(racers) do
        local id = scenetree.findObject(racers[i]):getId()
        local filename = "/replays/scriptai/tracks/"..filenames[i]..".track.json"
        local scriptData = jsonReadFile(filename)
        dump(scriptData)
        recordings[id] = scriptData.recording
        scenetree.findObject(racers[i]):queueLuaCommand("ai.startFollowing("..serialize(recordings[id])..")")
    end
end

local function onRaceWaypointReached(data)
  --log('I', logTag,'onRaceWaypointReached called ')
  --dump(data)
  if data.waypointName == finalWaypointName then
    if data.vehicleName == playerInstance and not aiWon then
      playerWon = true
    elseif data.vehicleName == aiInstance and not playerWon then
      aiWon = true
    end
  end
end

local function onRaceResult()
  if playerWon then
    success('scenarios.utah.chapter_2.chapter_2_6_canyon.pass.msg')
  else
    fail('scenarios.utah.chapter_2.chapter_2_6_canyon.fail.msg')
  end
end

local function onVehicleStoppedMoving(vehicleID, damaged)
  if running then
    local playerVehicleID = scenetree.findObject(playerInstance):getID()
    if vehicleID == playerVehicleID and damaged then
      if not playerWon then
        fail('scenarios.utah.chapter_2.chapter_2_6_canyon.fail.msg')
      end
    end
  end
end

M.onRaceStart = onRaceStart
M.onRaceWaypointReached = onRaceWaypointReached
M.onRaceResult = onRaceResult
M.onVehicleStoppedMoving = onVehicleStoppedMoving
return M